@@ -13,7 +13,7 @@ def get_only_func_decl(rest: str):
     res = reg.match(rest)
     if res != None:
         only_decl = rest[res.start():res.end()]
-        if "=" in only_decl:
+        if "=" in only_decl or ";" in only_decl:
             return ''
         return only_decl
     return ''
@@ -22,7 +22,7 @@ def check(context, file: CFileParse) -> (int, int, list):
     nb_error = 0
     list_error = []
 
-    if file.basename.endswith('.h'):
+    if file.basename.endswith('.h') or file.filepath.endswith("Makefile"):
         return (0, 0, [])
     for i, line in enumerate(file.sub_parsedline):
         if line[0] == TypeLine.COMMENT:
