@@ -33,7 +33,7 @@ UPDATE:
 CONFIGS:
     normatrix can read a special json file for configuration.
     -> put a `.normatrix.json` file on the path where tou execute normatrix
-    -> execute normatrix whit `--conf` command line argument
+    -> and execute normatrix like you did it before
 
     default configuration file:
         ```json
@@ -65,7 +65,7 @@ def call_argparse():
             help='add some plugin that are added recently')
     parser.add_argument('--conf', action='store_const',
             dest='configs', const='yes', default='no',
-            help='tells if you have a .normatrix config file')
+            help='[deprecated][check always for the file] tells if you have a .normatrix config file')
     parser.add_argument('--only-error', action='store_const',
             dest='only_error', const='yes', default='no',
             help='print only bad files with errors')
@@ -73,6 +73,9 @@ def call_argparse():
             choices=["html", "md", "term_color"], dest='output_format',
             default="term_color",
             help='tell which output format to use [html, md, term_color]; for html the file is normatrix-result.htmk; for md the file is normatrix-result.md')
+    parser.add_argument('--no-fclean', action='store_const',
+            dest='no_fclean', const=True, default=False,
+            help='if you want normatrix dont do a "make fclean" at the end')
     result = parser.parse_args()
     if result.paths == []:
         result.paths.append(os.getcwd())
@@ -94,7 +97,7 @@ def check_norm_path(pwd: str, context: Context, plug_operator_activ: bool, previ
         color.print_color("green", "\nNorMatrix!")
         color.print_color("cyan", f"directory to check: {pwd}\n")
 
-    stats, files_to_check = get_file_to_check.get_file_to_check(pwd)
+    stats, files_to_check = get_file_to_check.get_file_to_check(context, pwd)
 
     STATS, NB_ERROR = call_plugged.call_plugged(context, files_to_check, list_checkers, pwd)
 
@@ -118,6 +121,27 @@ def check_norm_path(pwd: str, context: Context, plug_operator_activ: bool, previ
             color.print_color("red", f"DUMB BRO ({NB_ERROR} error.s)")
         return NB_ERROR
 
+def transform_to_html(context: Context):
+    try:
+        from markdown import Markdown
+    except ModuleNotFoundError:
+        print("you should install the markdown package first (pip install markdown)")
+        exit(1)
+    to_file = context.output_file.replace(".md", ".html")
+    mark = Markdown()
+    mark.convertFile(input=context.output_file, output=to_file)
+    os.remove(context.output_file)
+    with open(to_file, "r") as file:
+        lines = file.readlines()
+    lines.insert(0, "<!DOCTYPE html>")
+    lines.insert(1, "<head>")
+    lines.insert(2, "<title>NorMatrix Results</title>")
+    lines.insert(3, "</head>")
+    lines.insert(4, "<body>")
+    lines.append("</body>")
+    with open(to_file, "w") as file:
+        file.writelines(lines)
+
 def main():
     result = call_argparse()
     ret_code = 0
@@ -125,10 +149,7 @@ def main():
     is_plugin_operator = result.plug_operator_activ == "yes"
     for path in result.paths:
         curr_ret_code = 0
-        if result.configs == "yes":
-            context = Context(os.path.join(path, ".normatrix.json"), result.only_error, result.output_format)
-        else:
-            context = Context(None, result.only_error, result.output_format)
+        context = Context(path, result.only_error, result.output_format, result.no_fclean)
         if check_norm_path(path, context, is_plugin_operator, is_preview) != 0:
             curr_ret_code += 1
         if makefile.check(context, path)[0] != 0:
@@ -142,12 +163,5 @@ def main():
         elif context.output_format == "term_color":
             print(f'\nYou Have {ret_code} folder.s that dont respect the norm')
     if result.output_format == "html":
-        try:
-            from markdown import Markdown
-        except ModuleNotFoundError:
-            print("you should install the markdown package first (pip install markdown)")
-            exit(1)
-        mark = Markdown()
-        mark.convertFile(input=context.output_file, output=context.output_file.replace(".md", ".html"))
-        os.remove(context.output_file)
+        transform_to_html(context)
     exit(0 if ret_code == 0 else 1)
